@@ -1,6 +1,6 @@
 /*
  *  R : A Computer Language for Statistical Data Analysis
- *  Copyright (C) 1998-2001  Marcus G. Daniels <mgd@swarm.org>
+ *  Copyright (C) 1998-2003  Marcus G. Daniels <mgd@swarm.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  */
 #define USE_RINTERNALS
 #include <Rinternals.h>
-#include <R_ext/Mathlib.h>
+#include <Rmath.h>
 #include <Rconfig.h>
 
 #include <hdf5.h>
